import VueI18n from 'vue-i18n'
import 'normalize.css/normalize.css'

import MakingForm from './components/Container.vue'
import GenerateForm from './components/GenerateForm.vue'

import enUS from './lang/en-US'
import zhCN from './lang/zh-CN'

import './iconfont/iconfont.css'
import './iconfont2/iconfont.css'
import './styles/cover.scss'
import './styles/index.scss'
import Print from 'vue-print-nb'

const loadLang = function (Vue, lang, locale, i18n) {
  if (locale) {
    locale('en-US', {...locale('en-US'), ...enUS})
    locale('zh-CN', {...locale('zh-CN'), ...zhCN})
    Vue.config.lang = lang
  } else if (i18n) {
    i18n.setLocaleMessage('en-US', {...i18n.messages['en-US'], ...enUS})
    i18n.setLocaleMessage('zh-CN', {...i18n.messages['zh-CN'], ...zhCN})
    i18n.locale = lang
  } else {
    Vue.use(VueI18n)
    let messages = {'zh-CN':{...zhCN}}
    // console.log('messages',messages)
    const i18n = new VueI18n({
      locale: 'zh-CN', // set locale
      messages, // set locale messages
    })

    //设置$t全局变量
    Vue.prototype.$t = (key, value) => i18n.t(key, value)

    /*修改前代码*/
    // Vue.use(VueI18n)
    // Vue.locale('en-US', {...Vue.locale('en-US'), ...enUS})
    // Vue.locale('zh-CN', {...Vue.locale('zh-CN'), ...zhCN})
    // Vue.config.lang = lang


  }
}

MakingForm.install = function (Vue, opts = {
  lang: 'zh-CN',
  locale: null,
  i18n: null
}) {
  loadLang(Vue, opts.lang, opts.locale, opts.i18n)
   Vue.use(Print);
  Vue.component(MakingForm.name, MakingForm)
}

GenerateForm.install = function (Vue, opts = {
  lang: 'zh-CN',
  locale: null,
  i18n: null
}) {
  loadLang(Vue, opts.lang, opts.locale, opts.i18n)
  Vue.use(Print);
  Vue.component(GenerateForm.name, GenerateForm)
}

const components = [
  MakingForm,
  GenerateForm
]

const install = function (Vue, opts = {
  lang: 'zh-CN',
  locale: null,
  i18n: null
}) {
  Vue.prototype.$formConfig = opts.formConfig || {}
  loadLang(Vue, opts.lang, opts.locale, opts.i18n)
  Vue.use(Print);
  components.forEach(component => {
    Vue.component(component.name, component)
  })
}

if (typeof window !== 'undefined' && window.Vue) {
  install(window.Vue);
}

export {
  install,
  MakingForm,
  GenerateForm
}

export default {
  install,
  MakingForm,
  GenerateForm
}
