/**
 * 校验身份证（含港澳台）
 * @param value 组件填写值
 * @param callback 回调函数
 * @returns {*}
 */
import {console} from "vuedraggable/src/util/helper";

function idCard({value,callback}){
    console.log('校验身份证（含港澳台）',value)
    let reg = /(^((\s?[A-Za-z])|([A-Za-z]{2}))\d{6}((\([0−9aA]\))|(\([0-9aA]\)))$)|(^[1|5|7][0-9]{6}\([0-9Aa]\))|(^[A-KM-QT-XZ]{1}[0-9]{9}$)|(^[1-9]\d{5}(16|17|18|19|20|(3\d))\d{2}((0[1-9])|(1[0-2]))(([0-2][1-9])|10|20|30|31)\d{3}[0-9X]$)/
    if(!reg.test(value)){
        callback(new Error('身份证格式不正确！'))
        return
    }else if(/[A-Z]{1}\\d{9}/.test(value)){
        //香港
        callback()
        return
    }else if(/[A-Z]{1}\\d{9}/.test(value)){
        //台湾
        callback()
        return
    }else {
        let Errors = [new Error("验证通过!"),
            new Error("身份证号码位数不对!"),
            new Error("身份证号码出生日期超出范围或含有非法字符!"),
            new Error("身份证号码校验错误!"),
            new Error("身份证地区非法!")];
        let area={11:"北京",12:"天津",13:"河北",14:"山西",15:"内蒙古",21:"辽宁",22:"吉林",23:"黑龙江",31:"上海",32:"江苏",33:"浙江",34:"安徽",35:"福建",36:"江西",37:"山东",41:"河南",42:"湖北",43:"湖南",44:"广东",45:"广西",46:"海南",50:"重庆",51:"四川",52:"贵州",53:"云南",54:"西藏",61:"陕西",62:"甘肃",63:"青海",64:"宁夏",65:"新疆",71:"台湾",81:"香港",82:"澳门",91:"国外"}
        let idcard = value;
        let S,M;
        let idcard_array = new Array();
        idcard_array = idcard.split("");
        //地区检验
        if(area[parseInt(idcard.substr(0,2))]==null) return callback(Errors[4]);
        //身份号码位数及格式检验
        let ereg = null
        switch(idcard.length){
            case 15:
                // console.log('执行动态校验函数身份号码位数15',value)
                if ( (parseInt(idcard.substr(6,2))+1900) % 4 === 0 || ((parseInt(idcard.substr(6,2))+1900) % 100 === 0 && (parseInt(idcard.substr(6,2))+1900) % 4 === 0 )){
                    ereg=/^[1-9][0-9]{5}[0-9]{2}((01|03|05|07|08|10|12)(0[1-9]|[1-2][0-9]|3[0-1])|(04|06|09|11)(0[1-9]|[1-2][0-9]|30)|02(0[1-9]|[1-2][0-9]))[0-9]{3}$/;//测试出生日期的合法性
                } else {
                    ereg=/^[1-9][0-9]{5}[0-9]{2}((01|03|05|07|08|10|12)(0[1-9]|[1-2][0-9]|3[0-1])|(04|06|09|11)(0[1-9]|[1-2][0-9]|30)|02(0[1-9]|1[0-9]|2[0-8]))[0-9]{3}$/;//测试出生日期的合法性
                }
                if(ereg.test(idcard)){
                    return callback();
                }else{
                    return callback(Errors[2]);
                }
                break;
            case 18:
                // console.log('执行动态校验函数身份号码位数18',value)
                //18位身份号码检测
                //出生日期的合法性检查
                //闰年月日:((01|03|05|07|08|10|12)(0[1-9]|[1-2][0-9]|3[0-1])|(04|06|09|11)(0[1-9]|[1-2][0-9]|30)|02(0[1-9]|[1-2][0-9]))
                //平年月日:((01|03|05|07|08|10|12)(0[1-9]|[1-2][0-9]|3[0-1])|(04|06|09|11)(0[1-9]|[1-2][0-9]|30)|02(0[1-9]|1[0-9]|2[0-8]))
                if ( parseInt(idcard.substr(6,4)) % 4 === 0 || (parseInt(idcard.substr(6,4)) % 100 === 0 && parseInt(idcard.substr(6,4))%4 === 0 )){
                    ereg=/^[1-9][0-9]{5}(19|20)[0-9]{2}((01|03|05|07|08|10|12)(0[1-9]|[1-2][0-9]|3[0-1])|(04|06|09|11)(0[1-9]|[1-2][0-9]|30)|02(0[1-9]|[1-2][0-9]))[0-9]{3}[0-9Xx]$/;//闰年出生日期的合法性正则表达式
                } else {
                    ereg=/^[1-9][0-9]{5}(19|20)[0-9]{2}((01|03|05|07|08|10|12)(0[1-9]|[1-2][0-9]|3[0-1])|(04|06|09|11)(0[1-9]|[1-2][0-9]|30)|02(0[1-9]|1[0-9]|2[0-8]))[0-9]{3}[0-9Xx]$/;//平年出生日期的合法性正则表达式
                }
                if(ereg.test(idcard)){//测试出生日期的合法性
                    //计算校验位
                    S = (parseInt(idcard_array[0]) + parseInt(idcard_array[10])) * 7
                        + (parseInt(idcard_array[1]) + parseInt(idcard_array[11])) * 9
                        + (parseInt(idcard_array[2]) + parseInt(idcard_array[12])) * 10
                        + (parseInt(idcard_array[3]) + parseInt(idcard_array[13])) * 5
                        + (parseInt(idcard_array[4]) + parseInt(idcard_array[14])) * 8
                        + (parseInt(idcard_array[5]) + parseInt(idcard_array[15])) * 4
                        + (parseInt(idcard_array[6]) + parseInt(idcard_array[16])) * 2
                        + parseInt(idcard_array[7]) * 1
                        + parseInt(idcard_array[8]) * 6
                        + parseInt(idcard_array[9]) * 3 ;
                    let Y = S % 11;
                    M = "F";
                    let JYM = "10X98765432";
                    M = JYM.substr(Y,1);//判断校验位
                    if(M === idcard_array[17]){
                        return callback(); //检测ID的校验位
                    }else{
                        return callback(Errors[3]);
                    }
                }else{
                    return callback(Errors[2]);
                }
                break;
            default:
                // console.log('执行动态校验函数身份号码位数默认',value)
                return callback();
        }
    }
    callback();
}

/**
 * 校验中文
 * @param value 组件填写值
 * @param widget 组件属性
 * @param callback 回调函数
 */
function chinese({value,widget,callback}) {
    let reg = /^[\u2E80-\u9FFF]+$/
    if(!reg.test(value)){
        callback(new Error((widget.name || '') + '格式不正确！'))
        return
    }
    callback()
}

/**
 * 校验手机号码
 * @param value 组件填写值
 * @param widget 组件属性
 * @param callback 回调函数
 */
function phone({value,widget,callback}) {
    let reg = /^1[3456789]\d{9}$/
    if(!reg.test(value)){
        callback(new Error('手机号码格式不正确！'))
        return
    }
    callback()
}

export default {
    idCard,
    chinese,
    phone
}
